@@ -1,6 +1,7 @@
 import random as rm
 import time
 import webbrowser as web
+import requests
 
 def help():
     print("example")
@@ -10,6 +11,7 @@ def help():
     print(" torancell.art()")
     print(" torancell.bogo(int)")
     print(" torancell.wiki()")
+    print(" torancell.weather()")
     
 def red():
     str = "かたい カラに つつまれているが なかみは やわらかいので つよい こうげきには たえられない。"
@@ -377,4 +379,31 @@ def bogo(i=200):
         time.sleep(0.2)
 
 def wiki(url='https://wiki.xn--rckteqa2e.com/wiki/%E3%83%88%E3%83%A9%E3%83%B3%E3%82%BB%E3%83%AB'):
-    web.open(url)
\ No newline at end of file
+    web.open(url)
+
+def weather():
+    city_name = "numazu"
+    app_id = "2fbd8984023b18b24537d4bb1bd1f3af"
+    #&units=metricで摂氏温度を求める
+    URL = "https://api.openweathermap.org/data/2.5/weather?q={0},jp&units=metric&lang=ja&appid={1}".format(city_name, app_id)
+
+    response = requests.get(URL)
+    data =  response.json()
+
+    #天気情報
+    weather = data["weather"][0]["description"]
+    #最高気温
+    temp_max = data["main"]["temp_max"]
+    #最低気温
+    temp_min = data["main"]["temp_min"]
+    #寒暖差
+    diff_temp = temp_max - temp_min
+    #湿度
+    humidity = data["main"]["humidity"]
+
+    # context = {"天気": weather, "最高気温":str(temp_max) + "度", "最低気温": str(temp_min) + "度", "寒暖差": str(diff_temp) + "度", "湿度": str(humidity) + "%"}
+    # print("---静岡県沼津市の天気---")
+    # for k, v in context.items():
+    #     print("{0}:{1}".format(k, v))
+
+    print("沼津市の現在の天気は["+weather+"]です。")
\ No newline at end of file
